@@ -17,12 +17,13 @@ from ujenkins.core import Jenkins, JenkinsError, JenkinsNotFoundError, Response
 
 class RetryClientSession:
 
-    def __init__(self, loop: Optional[asyncio.AbstractEventLoop], options: dict):
+    def __init__(self, options: dict) -> None:
         self.total = options['total']
         self.factor = options.get('factor', 1)
         self.statuses = options.get('statuses', [])
+        self.methods = options.get('methods', ['GET', 'POST', 'PATCH'])
 
-        self.session = ClientSession(loop=loop)
+        self.session = ClientSession()
 
     async def request(self, *args: Any, **kwargs: Any) -> ClientResponse:
         for total in range(self.total):
@@ -32,6 +33,8 @@ class RetryClientSession:
                 if total + 1 == self.total:
                     raise JenkinsError from e
             else:
+                if response.method.upper() not in self.methods:
+                    break
                 if response.status not in self.statuses:
                     break
 
@@ -53,11 +56,10 @@ class AsyncJenkinsClient(Jenkins):
                  user: Optional[str] = None,
                  password: Optional[str] = None,
                  *,
-                 loop: Optional[asyncio.AbstractEventLoop] = None,
                  verify: bool = True,
                  timeout: Optional[float] = None,
                  retry: Optional[dict] = None
-                 ):
+                 ) -> None:
         """
         Jenkins async client class.
 
@@ -66,14 +68,11 @@ class AsyncJenkinsClient(Jenkins):
                 URL of Jenkins server.
 
             user (Optional[str]):
-                User name, login.
+                User name.
 
             password (Optional[str]):
                 Password for user.
 
-            loop (Optional[AbstractEventLoop]):
-                Asyncio current event loop.
-
             verify (Optional[bool]):
                 Verify SSL (default: true).
 
@@ -105,7 +104,6 @@ class AsyncJenkinsClient(Jenkins):
         """
         super().__init__()
 
-        self.loop = loop or asyncio.get_event_loop()
         self.host = url.rstrip('/')
         self.crumb = None  # type: Any
 
@@ -115,9 +113,9 @@ class AsyncJenkinsClient(Jenkins):
 
         if retry:
             self._validate_retry_argument(retry)
-            self.session = RetryClientSession(loop, retry)
+            self.session = RetryClientSession(retry)
         else:
-            self.session = ClientSession(loop=self.loop)
+            self.session = ClientSession()
 
         self.verify = verify
 
@@ -128,7 +126,7 @@ class AsyncJenkinsClient(Jenkins):
                             method: str,
                             path: str,
                             *,
-                            callback: Optional[Callable] = None,
+                            _callback: Optional[Callable] = None,
                             **kwargs: Any
                             ) -> Any:
 
@@ -151,7 +149,7 @@ class AsyncJenkinsClient(Jenkins):
 
         result = self._process(
             Response(response.status, response.headers, body),
-            callback
+            _callback
         )
 
         return result
